%
%  wuthesis.cls  2006-12-19  
%
%    Steven Xiao 
%
%	10/30/2014, revised by Yao Xie
%
%  INDEX: Washington University Department of Mathematics thesis document class
%
%  DESCRIPTION:
%
%    This is a LaTeX document class for Washington University Department of Mathematics theses.
%
%  USAGE:
%
%    \documentclass{wuthesis}.
%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{wuthesis}[10/30/2014 Wash U Math thesis class]
\usepackage{cite}
\usepackage{ifthen}
\newcommand{\ifthen}[2]{\ifthenelse{#1}{#2}{}}
\usepackage{endnotes}
%\usepackage{wulongtable}
\usepackage{rotating}
\usepackage{lscape}

\usepackage{amsmath}
\usepackage{amsfonts}
\usepackage{array}
\usepackage{multirow}

\makeatletter

\def\@@number{\string##}

\newcounter{@@tcount}
\newcounter{@@volume}
\newcounter{last@@volume}
\newcounter{save@@page}
\newlength{\@@captionwidth}  
\newlength{\@@parindent}  \setlength{\@@parindent}{\parindent}
\newlength{\@@padding}
\newlength{\@@tlength}
\newcommand{\@@dept}{unknown}
\newcommand{\set@@dept}[1]{\renewcommand{\@@dept}{math}}
\newcommand{\wendnotes}{}
\DeclareOption{endnotes}{%
  \let\footnote=\endnote
  \renewcommand{\wendnotes}{%
    \newpage
    \begingroup
      \setlength{\parindent}{0pt}
      \setlength{\parskip}{1.5ex}
      \renewcommand{\enotesize}{\normalsize}
      \theendnotes
    \endgroup
  }
}
\newcommand{\@@type}{thesis}
\newcommand{\set@@type}[1]{\renewcommand{\@@type}{#1}}
\DeclareOption{bypass}{\set@@type{bypass}}
\DeclareOption{prelim}{\set@@type{prelim}}
\DeclareOption{thesis}{\set@@type{thesis}}
\newboolean{@@uglyheadings}
\setboolean{@@uglyheadings}{false}
\DeclareOption{uglyheadings}{\setboolean{@@uglyheadings}{true}}
\newboolean{@@unset}
\newcommand{\@@optionbibstyle}{}
\newcommand{\set@@optionbibstyle}[1]{\renewcommand{\@@optionbibstyle}{#1}\addtocounter{@@tcount}{1}}
\DeclareOption{abbrvnat}{\set@@optionbibstyle{abbrvnat}}
\DeclareOption{agsm}{\set@@optionbibstyle{agsm}}
\DeclareOption{aip}{\set@@optionbibstyle{aip}}
\DeclareOption{alpha}{\set@@optionbibstyle{alpha}}
\DeclareOption{apalike}{\set@@optionbibstyle{apalike}}
\DeclareOption{astron}{\set@@optionbibstyle{astron}}
\DeclareOption{chicago}{\set@@optionbibstyle{chicago}}
\DeclareOption{ieee}{\set@@optionbibstyle{ieee}}
\DeclareOption{ieeetr}{\set@@optionbibstyle{ieeetr}}
\DeclareOption{kluwer}{\set@@optionbibstyle{kluwer}}
\DeclareOption{plain}{\set@@optionbibstyle{plain}}
\DeclareOption{plainnat}{\set@@optionbibstyle{plainnat}}
\DeclareOption{unsrt}{\set@@optionbibstyle{unsrt}}
\DeclareOption{unsrtnat}{\set@@optionbibstyle{unsrtnat}}
\newif\if@openbib
\@openbibfalse
%
\newboolean{@@nonchapterblankpages}
\setboolean{@@nonchapterblankpages}{false}
\newcommand{\nonchapterblankpages}{\setboolean{@@nonchapterblankpages}{true}}
\newcommand{\nononchapterblankpages}{\setboolean{@@nonchapterblankpages}{false}}
\DeclareOption{nonchapterblankpages}{\nonchapterblankpages}
\DeclareOption{nononchapterblankpages}{\nononchapterblankpages}
%
\newboolean{@@chapterblankpages}
\setboolean{@@chapterblankpages}{true}
\newcommand{\chapterblankpages}{\setboolean{@@chapterblankpages}{true}}
\newcommand{\nochapterblankpages}{\setboolean{@@chapterblankpages}{false}}
\DeclareOption{chapterblankpages}{\chapterblankpages}
\DeclareOption{nochapterblankpages}{\nochapterblankpages}
%
\newboolean{@@coversheets}
\setboolean{@@coversheets}{true}
\newcommand{\coversheets}{\setboolean{@@coversheets}{true}}
\newcommand{\nocoversheets}{\setboolean{@@coversheets}{false}}
\DeclareOption{coversheets}{\coversheets}
\DeclareOption{nocoversheets}{\nocoversheets}
%
\DeclareOption{miser}{
  \nononchapterblankpages
  \nochapterblankpages
  \nocoversheets
}
\DeclareOption{nomiser}{
  \nonchapterblankpages
  \chapterblankpages
  \coversheets
}

\newboolean{number@@all@@volumes}
\setboolean{number@@all@@volumes}{false}
\DeclareOption{numberallvolumes}{\setboolean{number@@all@@volumes}{true}}
\DeclareOption{nonumberallvolumes}{\setboolean{number@@all@@volumes}{false}}

%\DeclareOptions*(\PassOptionsToClass{\CurrentOption}{report}}
  % Used to count number of citation/bibliography styles used.
\setcounter{@@tcount}{0}
\ProcessOptions
\newcommand{\IW}[1]{\immediate\write16{#1}}
{
  \catcode`\+=13
  \def+{\space}
  \ifnum\value{@@tcount}>1
    \IW{}
    \IW{You may specify only one citation/bibliography style from the below list:}
    \IW{++++abbrvnat}
    \IW{++++agsm}
    \IW{++++aip}
    \IW{++++alpha}
    \IW{++++apalike}
    \IW{++++astron}
    \IW{++++chicago}
    \IW{++++ieee}
    \IW{++++ieeetr}
    \IW{++++kluwer}
    \IW{++++plain}
    \IW{++++plainnat}
    \IW{++++unsrt}
    \IW{++++unsrtnat}
    \IW{ABORTING...}
    \IW{}
    \stop
  \fi
}

\LoadClass[12pt]{report}[2001/04/21]

% Got these lines using "grep dotted report.cls" and changed
% as needed for new \@dottedtocline \vskip parameter.
\renewcommand*\l@section{\@dottedtocline{1}{\smalltocskip}{1.5em}{2.3em}}
\renewcommand*\l@subsection{\@dottedtocline{2}{\smalltocskip}{3.8em}{3.2em}}
\renewcommand*\l@subsubsection{\@dottedtocline{3}{\smalltocskip}{7.0em}{4.1em}}
\renewcommand*\l@paragraph{\@dottedtocline{4}{\smalltocskip}{10em}{5em}}
\renewcommand*\l@subparagraph{\@dottedtocline{5}{\smalltocskip}{12em}{6em}}
\renewcommand*\l@figure{\@dottedtocline{1}{\bigtocskip}{0em}{2.3em}}
\renewcommand*\l@table{\@dottedtocline{1}{\bigtocskip}{0em}{2.3em}}

{\obeyspaces
  \gdef\@@Identification{{
    \IW{}
    \IW{+----------------------------------------------------------------------------+}
    \IW{|                                                                            |}
    \IW{|                         Thanks for using wuthesis.cls.                     |}
    \IW{|                                                                            |}
    \IW{+----------------------------------------------------------------------------+}
    \IW{}
}}
}

\def\AppendixFigure{\relax}
\def\AppendixTable{\relax}
\def\@@bibname{REFERENCES}
\def\@@deptbibstyle{unsrt}
\def\@@coversheetspace{\vfill}
\def\@@evenfoot{}
\def\@@evenhead{\hfil\textrm{\thepage}}
\newboolean{@@figurecaptions}
  \setboolean{@@figurecaptions}{false}
\def\@@oddfoot{}
\def\@@oddhead{\hfil\textrm{\thepage}}
\def\@@sectionbaselinestretch{\relax}
\def\@@sectionseries{\bfseries}
\def\@@startthebibliography{\coversheet{\@@bibname}}
\def\@@startvita{\coversheet{\@@vitaname}}
\def\@@subsectionbaselinestretch{\relax}
\def\@@subsectionseries{\bfseries}
\def\@@subsubsectionbaselinestretch{\relax}
\def\@@subsubsectionseries{\bfseries}
\def\@@t{\relax}
\def\@@thebibliographyparsep{\relax}
\def\@@makechapterhead#1{\large\bf\thechapter. #1}
\def\@@makechapterheadspacea{\vspace*{0.5truein}}
\def\@@makechapterheadspaceb{\vspace{0.5\baselineskip}}
\def\@@makeschapterheadspacea{\vspace*{0.5truein}}
\def\@@makeschapterheadspaceb{\vspace*{0.5\baselineskip}}
\AtBeginDocument{
  \usepackage{notoccite}
}
\AtEndDocument{
  \@@Identification
%%  \write\@auxout{\string\newcounter{\string\csname@@@appendix\endcsname}}
%%  \write\@auxout{\string\setcounter{\string\csname@@@appendix\endcsname}{\arabic{@@appendix}}}
}
\newenvironment{cland}
  {\begin{landscape}\hbox\bgroup\hss\vbox\bgroup}
  {\egroup\hss\egroup\end{landscape}}

\newenvironment{lquotation}
  {\begin{quotation}\renewcommand{\baselinestretch}{1}\reset@font}
  {\end{quotation}}

\newcommand{\coversheet}[1]{
  {
    \ifthen{\boolean{@@coversheets}}
      {
        \ifthenelse{\boolean{@@chapterblankpages}}
          {\clearpage} %% ! {\cleardoublepage}
          {\clearpage}
        \pagestyle{empty}
        \mbox{}
        \@@coversheetspace
        \begin{center}
          #1
        \end{center}
        \vfill
        \newpage
        \addtocounter{page}{-1}
      }
    \@@NotTableOfContents
  }
}

% change margin
% page: 597 x 845 points

\setlength{\oddsidemargin}{0pt}
\setlength{\evensidemargin}{0pt}
\setlength{\textwidth}{453pt}
\setlength{\voffset}{-57pt}
\setlength{\topmargin}{20pt}
\setlength{\headheight}{12pt}
\setlength{\headsep}{25pt}
\setlength{\textheight}{701pt}

\renewcommand*{\baselinestretch}{2}


\clubpenalty=10000
\widowpenalty=10000
\displaywidowpenalty=10000
\pagenumbering{roman}

\newcommand{\@@NotTableOfContents}{%
  \renewcommand*{\@evenhead}{\@@evenhead}
  \renewcommand*{\@oddhead}{\@@oddhead}
  \renewcommand*{\@evenfoot}{\@@evenfoot}
  \renewcommand*{\@oddfoot}{\@@oddfoot}
}
\@@NotTableOfContents


\newcommand*{\@@TitleAuthor}{\relax}
\newcommand*{\@@AbstractAuthor}{\relax}
\renewcommand*{\author}[2]{%
  \renewcommand*{\@@TitleAuthor}{#1}%
  \renewcommand*{\@@AbstractAuthor}{#2}%
}




\newcommand*{\@@TitleDegree}{\relax}
\newcommand*{\@@AbstractDegree}{\relax}
\newcommand*{\@@DegreeMonth}{\relax}
\newcommand*{\@@DegreeYear}{\relax}
\newcommand*{\wudegree}[4]{%
  \renewcommand*{\@@TitleDegree}{#1}%
  \renewcommand*{\@@AbstractDegree}{#2}%
  \renewcommand*{\@@DegreeMonth}{#3}%
  \renewcommand*{\@@DegreeYear}{#4}%
}




\newcommand*{\@@MajorProf}{\relax}
\newcommand*{\majorprof}[1]{\renewcommand*{\@@MajorProf}{Professor #1, Chair}}
\newcommand*{\majorprofs}[1]{\renewcommand*{\@@MajorProf}{Major Professors: #1}}
\newcommand*{\@@Title}{\relax}
\renewcommand*{\title}[1]{\renewcommand*{\@@Title}{#1}}
\newcommand*{\@@Committee}{\relax}
\newcommand*{\committee}[1]{\renewcommand*{\@@Committee}{#1}}



% title page

\renewcommand*{\maketitle}
  {
    {
      \renewcommand*{\baselinestretch}{2} \reset@font
      \setcounter{save@@page}{\value{page}}
      \begin{titlepage}
        \mbox{}
        \vfil
        \vfil
        \begin{center}
        {WASHINGTON UNIVERSITY IN ST. LOUIS\\}
        {Department of Mathematics }
        \vskip 0.4truein
	\renewcommand{\baselinestretch}{1.5}\reset@font
        { Dissertation Examination Committee:\\
         \@@Committee
        }
	\renewcommand{\baselinestretch}{2}\reset@font
        \vskip 0.5truein
        \expandafter{\@@Title}
        \end{center}
        \ifthen{\(\boolean{number@@all@@volumes} \and \value{last@@volume}>1\) \or \value{@@volume}>1}
          {
            \begin{center}
              VOLUME \the@@volume
            \end{center}
          }
        \vfil
        \begin{center}
          by\\
          \@@TitleAuthor
        \end{center}
        \vfil
        \renewcommand{\baselinestretch}{1.5}\reset@font
        \begin{center}
          A dissertation presented to the \\ Graduate School of Arts \& Sciences\\ of Washington University in\\ partial fulfillment of the\\
          requirements for the degree\\
          of
          \@@TitleDegree
        \end{center}
          {}
          {\vfil}
        \begin{center}
          \@@DegreeMonth\ \@@DegreeYear\\
          St. Louis, Missouri 
        \end{center}
      \end{titlepage}
      \setcounter{page}{\value{save@@page}}
      \ifthen{\value{@@volume}=0 \or \value{@@volume}=1}
        {\setcounter{page}{2}}
    }
  }





% dedication page

\newenvironment{dedication}%
  {%
    \newpage
    \pagestyle{plain}
    \mbox{}
    \vfil
    \begin{center}%
  }%
  {%
    \end{center}%
    \vfil
    \eject
    \@@NotTableOfContents
  }
  
  
  
\newboolean{@@inother}
\setboolean{@@inother}{false}
  % #1 "next" or "odd": start on next or next odd page?
  % #2 what to print at top of page
  % #3 "y" or "n": put in table of contents?
  % #4 amount of extra space to put after heading at top of page
  
\newcommand{\@@nonchapter}[4]{{%
  \@@NotTableOfContents
  \bgroup
    \pagestyle{plain}
    \setboolean{@@inother}{true}
    \renewcommand{\large}{}%
    \renewcommand{\bf}{}%
    \ifthenelse{\equal{ce}{\@@dept}}
      {\chapter*{\uppercase{#2}}}
      {\chapter*{#2}}
    \ifthen{\equal{y}{#3}}
      {
        \ifthenelse{\equal{ce}{\@@dept}}
          {\addcontentsline{toc}{chapter}{\uppercase{#2}}}
          {\addcontentsline{toc}{chapter}{#2}}
      }
  \egroup
  \vspace{#4}
}}


% acknowledgment page

\newenvironment{acknowledgments}%
  {\@@nonchapter{next}{Acknowledgments}{y}{0pt}}%
  {}
  
% preface page
\newenvironment{preface}%
  {\@@nonchapter{next}{PREFACE}{y}{0pt}}%
  {}
  
  
% table of contents page
\renewcommand*{\tableofcontents}{
  \@@nonchapter{odd}{Table of Contents}{n}{0pt}
  {\leftskip=0pt \noindent\hbox to\textwidth{\hfil Page}\par}
  {%
    \output={
      \let \par \@@par
      \ifnum \outputpenalty<-\@M
        \@specialoutput
      \else
        \@makecol
        \@opcol
        \@startcolumn
        \@whilesw \if@fcolmade \fi
          {%
           \@opcol\@startcolumn}%
      \fi
      \ifnum \outputpenalty>-\@Miv
        \ifdim \@colroom<1.5\baselineskip
          \ifdim \@colroom<\textheight
            \@latex@warning@no@line{Text page \thepage\space
              contains only floats}%
            \@emptycol
          \else
            \global \vsize \@colroom
          \fi
        \else
          \global \vsize \@colroom
        \fi
      \else
        \global \vsize \maxdimen
      \fi
      {\leftskip=0pt \noindent\hbox to\textwidth{\hfil Page}\par}
    }
    \renewcommand{\baselinestretch}{1.15}\reset@font
    \pagestyle{plain}
    \@starttoc{toc}
  }
}


\def\bigtocskip{0.5\baselineskip plus.2\p@}
\def\smalltocskip{0pt}

\def\@dottedtocline#1#2#3#4#5#6{%
  \ifnum #1>\c@tocdepth
  \else
    \vskip #2
    {%
      \leftskip #3
      \rightskip \@tocrmarg
      \parfillskip -\rightskip
      \parindent #3
      \@afterindenttrue
      \interlinepenalty\@M
      \leavevmode
      \@tempdima #4
      \advance\@tempdima \@@padding
      \advance\leftskip \@tempdima
      \hbox{}\hskip -\leftskip
      #5\nobreak
      \leaders\hbox{$\m@th \mkern \@dotsep mu.\mkern \@dotsep mu$}\hfill
      \nobreak
      \hbox to\@pnumwidth{\hfil\reset@font\rm #6}\par
    }%
  \fi
}


% list of tables page

\renewcommand*{\listoftables}{
  \@@nonchapter{next}{List of Tables}{y}{0pt}
  {\leftskip=0pt \noindent\hbox to\textwidth{Table\hfil Page}\par}
  {%
    \output={
      \let \par \@@par
      \ifnum \outputpenalty<-\@M
        \@specialoutput
      \else
        \@makecol
        \@opcol
        \@startcolumn
        \@whilesw \if@fcolmade \fi
          {%
           \@opcol\@startcolumn}%
      \fi
      \ifnum \outputpenalty>-\@Miv
        \ifdim \@colroom<1.5\baselineskip
          \ifdim \@colroom<\textheight
            \@latex@warning@no@line{Text page \thepage\space
              contains only floats}%
            \@emptycol
          \else
            \global \vsize \@colroom
          \fi
        \else
          \global \vsize \@colroom
        \fi
      \else
        \global \vsize \maxdimen
      \fi
      {\leftskip=0pt \noindent\hbox to\textwidth{Table\hfil Page}\par}
    }
    \renewcommand{\baselinestretch}{1.15}\reset@font
    \@starttoc{lot}
  }
}


% list of figures page

\renewcommand{\listoffigures}{
  \@@nonchapter{next}{List of Figures}{y}{0pt}
  {\leftskip=0pt \noindent\hbox to\textwidth{Figure\hfil Page}\par}
  {%
    \output={
      \let \par \@@par
      \ifnum \outputpenalty<-\@M
        \@specialoutput
      \else
        \@makecol
        \@opcol
        \@startcolumn
        \@whilesw \if@fcolmade \fi
          {%
           \@opcol\@startcolumn}%
      \fi
      \ifnum \outputpenalty>-\@Miv
        \ifdim \@colroom<1.5\baselineskip
          \ifdim \@colroom<\textheight
            \@latex@warning@no@line{Text page \thepage\space
              contains only floats}%
            \@emptycol
          \else
            \global \vsize \@colroom
          \fi
        \else
          \global \vsize \@colroom
        \fi
      \else
        \global \vsize \maxdimen
      \fi
      {\leftskip=0pt \noindent\hbox to\textwidth{Figure\hfil Page}\par}
    }
    \renewcommand{\baselinestretch}{1.15}\reset@font
    \@starttoc{lof}
  }
}



\newcommand{\@@startlist}[1]{
  \@@nonchapter{odd}{#1}{y}{0pt}%
  \setlength{\LTleft}{\parindent}%
  \setlength{\LTright}{0truein}%
  \setlength{\@@tlength}{\textwidth}
  \addtolength{\@@tlength}{-\LTleft}
  \addtolength{\@@tlength}{-\LTright}
  \addtolength{\@@tlength}{-\tabcolsep}
  \addtolength{\@@tlength}{-\tabcolsep}
  \addtolength{\@@tlength}{-1truein}
}



\newenvironment{symbols}%
  {%
    \@@startlist{SYMBOLS}
    \begin{longtable}{lp{\@@tlength}}%
  }
  {\end{longtable}}
\newenvironment{abbreviations}
  {
    \@@startlist{ABBREVIATIONS}
    \begin{longtable}{lp{\@@tlength}}%
  }
  {\end{longtable}}
\newenvironment{nomenclature}
  {
    \@@startlist{NOMENCLATURE}
    \begin{longtable}{lp{\@@tlength}}%
  }
  {\end{longtable}}
\renewenvironment{glossary}
  {
    \@@startlist{GLOSSARY}
    \begin{longtable}{lp{\@@tlength}}%
  }
  {\end{longtable}}


% abstract page

\renewenvironment{abstract}%
  {%
    \@@nonchapter{next}{ABSTRACT OF THE DISSERTATION}{y}{0pt}
    {%
      \renewcommand*{\baselinestretch}{1.5}\reset@font
      \vspace*{\baselineskip}
      \vbox{
        \begin{center}
        \noindent
        {\@@Title}\\
         by\\
        \@@AbstractAuthor~\\ \@@AbstractDegree \ in Mathematics,\\
        Washington University in St. Louis,
        \@@DegreeYear.\\
        {%
          \renewcommand*{\\}{}%
        }
        \@@MajorProf
       \end{center}
      }

      \vspace*{\baselineskip}
      \par
    }
  }%
  {\par}
  \pagestyle{plain}

\renewcommand{\chapter}{%
  \ifthenelse{
        \(      \boolean{@@inother} \and \boolean{@@nonchapterblankpages} \)
    \or \( \not \boolean{@@inother} \and \boolean{@@chapterblankpages}    \)
  }
    {\cleardoublepage}
    {\clearpage}
  \@@NotTableOfContents
  \global\@topnum\z@
  \@afterindentfalse
  \secdef \@chapter \@schapter
}


\newboolean{@@inchapters}
\setboolean{@@inchapters}{false}
\def\@chapter[#1]#2{%
  \ifnum \c@secnumdepth >\m@ne
    \refstepcounter{chapter}%
    \typeout{\@chapapp\space\thechapter.}%
    \setboolean{@@unset}{true}
  \fi
  \chaptermark{#1}%
  \ifthenelse{\equal{ce}{\@@dept}}
    {\@makechapterhead{\uppercase{#2}}}
    {\@makechapterhead{#2}}
  \@afterheading
  \ifthen{\not \boolean{@@inchapters}}
    {
      \pagenumbering{arabic}%
      \@@inchapterstrue
    }
  \pagestyle{plain}
  \addcontentsline{toc}{chapter}{{\protect\numberline{\csname thechapter\endcsname}{\bf #1}}}
}
\def\@makechapterhead#1{%
  \@@makechapterheadspacea
  {\centering
    \@@makechapterhead{#1}
    \endgraf
  }
  \@@makechapterheadspaceb
}
\def\@makeschapterhead#1{%
  \@@makeschapterheadspacea
  {\centering
    \ifthenelse{\equal{ce}{\@@dept}}
      {\large\bf\uppercase{#1}}
      {\large\bf#1}
    \endgraf
  }
  \@@makeschapterheadspaceb
}
\def\@startsection#1#2#3#4#5#6{%
  \if@noskipsec
    \leavevmode
  \fi
  \par
  \@tempskipa #4\relax
  \@afterindenttrue
  \ifdim \@tempskipa <\z@
    \@tempskipa -\@tempskipa
  \fi
  \if@nobreak
    \everypar{}%
  \else
    \addpenalty{\@secpenalty}%
    \addvspace{\@tempskipa}%
  \fi
  \@ifstar
    {\@ssect{#3}{#4}{#5}{#6}}%
    {\@dblarg{\@sect{#1}{#2}{#3}{#4}{#5}{#6}}}%
}



\newenvironment{cabstract}{\begin{quote}\textbf{Abstract}\quad}{\end{quote}}
\newtheorem{definition}{Definition}[section]
\newtheorem{observation}{Observation}[section]
\newsavebox{\proofbox}
\sbox{\proofbox}{\rule{7pt}{7pt}}
\newtheorem{Proof}{Proof}
\renewcommand{\theProof}{}
\newenvironment{proof}{\begin{Proof}\rm}{\hfill \usebox{\proofbox} \end{Proof}}
\newtheorem{proposition}{Proposition}[section]
\newtheorem{theorem}{Theorem}[section]
\renewcommand{\section}{%
  \@startsection
    {section}%
    {1}%
    {\z@}%
    {24pt}%
    {12pt}%
    {\@@sectionbaselinestretch\reset@font\@@sectionseries}%
}
\ifthen{\boolean{@@uglyheadings}}
  {
    \def\undertext#1{$\underline{\smash{\hbox{#1}}}$}
    \def\section{
      \vspace{36truept}
      \secdef{\@@section}{\@@ssection}
    }
    \def\@@section[#1]#2{
      \refstepcounter{section}
      \sectionmark{#1}
      \hbox to \textwidth{\hss\undertext{\thesection\ #2}\hss}\nopagebreak
      \addcontentsline{toc}{section}{\protect\numberline{\csname thesection\endcsname}#1}
      \nopagebreak
    }
    \def\@@ssection#1{
      \sectionmark{#1}
      \hbox to \textwidth{\hss\undertext{#1}\hss}\nopagebreak
      \nopagebreak
    }
  }
\renewcommand{\subsection}{%
  \@startsection
    {subsection}%
    {2}%
    {\z@}%
    {24pt}% \@plus -1ex \@minus -.2ex}%
    {12pt}% 1.5ex \@plus .2ex}%
    {\@@subsectionbaselinestretch\reset@font\@@subsectionseries}%
}
\ifthen{\boolean{@@uglyheadings}}
  {
    \renewcommand{\subsection}[1]{
      \refstepcounter{subsection}
      \vspace{36truept}
      \subsectionmark{#1}
      \hbox to \textwidth{\hss\thesubsection\ #1\hss}\nopagebreak
      \addcontentsline{toc}{subsection}{\protect\numberline{\csname thesubsection\endcsname}#1}
      \nopagebreak
    }
  }
\renewcommand{\subsubsection}{
  \@startsection
    {subsubsection}%
    {3}%
    {\z@}%
    {24pt}% \@plus -1ex \@minus -.2ex}%
    {12pt}% 1.5ex \@plus .2ex}%
    {\@@subsubsectionbaselinestretch\reset@font\@@subsubsectionseries}%
}
\ifthen{\equal{mse}{\@@dept}}
  {
    \def\undertext#1{$\underline{\hbox{#1}}$}
    \newbox{\@@Strut}
    \renewcommand{\subsubsection}[1]{
      \refstepcounter{subsubsection}
      \vspace{6truept}
      \subsubsectionmark{#1}
      \noindent \undertext{\vphantom{gjpqy}\thesubsubsection. #1}\newline\nopagebreak
      \addcontentsline{toc}{subsubsection}{\protect\numberline{\csname thesubsubsection\endcsname}#1}%
      \nopagebreak\indent
    }
  }
\ifthen{\boolean{@@uglyheadings}}
  {
    \renewcommand{\subsubsection}[1]{
      \refstepcounter{subsubsection}
      \vspace{36truept}
      \subsubsectionmark{#1}
      \noindent \undertext{\thesubsubsection. #1}\newline\nopagebreak
      \addcontentsline{toc}{subsubsection}{\protect\numberline{\csname thesubsubsection\endcsname}#1}
      \nopagebreak
    }
  }
\ifthen{\boolean{@@uglyheadings}}
  {
    \setcounter{tocdepth}{4}
    \newcommand*{\l@subsubsubsection}{\@dottedtocline{4}{\smalltocskip}{11.2em}{5.0em}}
    \def\subsubsubsectionmark#1{}
    \newcounter{subsubsubsection}[subsubsection]
    \renewcommand{\thesubsubsubsection}{\thesubsubsection.\arabic{subsubsubsection}}
    \newcommand{\subsubsubsection}[1]{
      \refstepcounter{subsubsubsection}
      \vspace{36truept}
      \subsubsubsectionmark{#1}
      \noindent \thesubsubsubsection. #1\newline\nopagebreak
      \addcontentsline{toc}{subsubsubsection}{\protect\numberline{\csname thesubsubsubsection\endcsname}#1}
      \nopagebreak
    }
  }
\def\@sect#1#2#3#4#5#6[#7]#8{%
  \ifnum #2>\c@secnumdepth
    \let\@svsec\@empty
  \else
    \refstepcounter{#1}%
    \edef\@svsec{\csname the#1\endcsname\hskip 1em}%
  \fi
  \ifthen{\equal{che}{\@@dept}}
    {%
      \ifnum #2=3
        \refstepcounter{#1}%
        \edef\@svsec{\csname the#1\endcsname\hskip 1em}%
      \fi
    }%
  \@tempskipa #5\relax
  \ifdim \@tempskipa>\z@
    \begingroup
      #6\relax
      \@hangfrom{\hskip #3\relax\@svsec}%
      {\interlinepenalty \@M #8\par}%
    \endgroup
    \csname #1mark\endcsname{#7}%
    \addcontentsline{toc}{#1}{%
      \ifnum #2>\c@secnumdepth
      \else
        \protect\numberline{\csname the#1\endcsname}%
      \fi
      #7%
    }%
  \else
    \def\@svsechd{%
      #6%
      \hskip #3\relax
      \@svsec #8\csname #1mark\endcsname
      {#7}%
      \addcontentsline{toc}{#1}{%
        \ifnum #2>\c@secnumdepth
        \else
          \protect\numberline{\csname the#1\endcsname}
        \fi
        #7%
      }%
    }%
  \fi
  \@xsect{#5}%
}






\renewcommand*{\l@chapter}{\@dottedtocline{0}{\bigtocskip}{0em}{1.4em}}
\ifthen{\equal{ece}{\@@dept}\or \equal{hsci}{\@@dept}}
  {\renewcommand{\figurename}{Fig.}}
\renewcommand{\fnum@figure}{\figurename~\thefigure.}
\renewcommand{\fnum@table}{\tablename~\thetable}
\newboolean{@@centercaption}
\renewcommand{\caption}{%
  \setboolean{@@centercaption}{true}
  \refstepcounter\@captype \@dblarg{\@caption\@captype}%
}
\newcommand\bcaption{%
  \setboolean{@@centercaption}{true}
  \refstepcounter\@captype \@dblarg{\@caption\@captype}%
}
\long\def\@makecaption#1#2{%
  \vspace*{\abovecaptionskip}
  \ifthenelse{\boolean{@@centercaption}}  % center caption
    {
      \setlength{\@@captionwidth}{\textwidth}
      \addtolength{\@@captionwidth}{-4\@@parindent}
      \ifthenelse{\equal{figure}{\@captype} \or \boolean{@@figurecaptions}}
        {
          \sbox\@tempboxa{#1 #2}%
          \renewcommand{\baselinestretch}{1.0}\reset@font
          \ifdim \wd\@tempboxa >\hsize
            \centerline{\parbox[t]{\@@captionwidth}{#1 #2}}
          \else
            \centerline{#1 #2}%
          \fi
        }
        {
          \renewcommand{\baselinestretch}{1.0}\reset@font
          \centerline{#1}
          \sbox\@tempboxa{#2}%
          \ifdim \wd\@tempboxa >\hsize
            \centerline{\parbox[t]{\@@captionwidth}{#2}}
          \else
            \centerline{#2}%
          \fi
        }
      \vspace*{\belowcaptionskip}
    }
    {
      \setlength{\topsep}{0pt}
      \setlength{\parskip}{0pt}
      \setlength{\partopsep}{0pt}
      \begin{quote}
        \renewcommand{\\}{}
        \renewcommand{\baselinestretch}{1.0}\reset@font
        \ifthenelse{\equal{aae}{\@@dept}}
          {#1. #2\par}
          {
            \ifthenelse{\equal{table}{\@captype}}
              {\hfil\strut #1\hfil\break #2\par}
              {#1 #2\par}
          }
      \end{quote}
    }
  \vskip\belowcaptionskip
}
\setlength\belowcaptionskip{5\p@}
\long\def\@makefntext#1{%
  \baselineskip=12pt
  \noindent
  \@makefnmark #1%
}
\ifthenelse{\equal{}{\@@optionbibstyle}}
  {\newcommand{\@@bibstyle}{\@@deptbibstyle}}
  {\newcommand{\@@bibstyle}{\@@optionbibstyle}}
\ifthen{\equal{abbrvnat}{\@@bibstyle}}
  {
    \usepackage{natbib}
    \renewcommand{\bibname}{{\normalsize\rm REFERENCES}}
    \bibliographystyle{abbrvnat}
  }
\ifthen{\equal{agsm}{\@@bibstyle}}
  {
    \usepackage{harvard}
    \bibliographystyle{agsm}
  }
\ifthen{\equal{aip}{\@@bibstyle}}
  {
    \usepackage{revtex}
    \renewcommand{\bibname}{{\normalsize\rm REFERENCES}}
    \bibliographystyle{aip}
  }
\ifthen{\equal{alpha}{\@@bibstyle}}
  {\bibliographystyle{alpha}}
\ifthen{\equal{apalike}{\@@bibstyle}}
  {\bibliographystyle{apalike}}
\ifthen{\equal{astron}{\@@bibstyle}}
  {\bibliographystyle{astron}}
\ifthen{\equal{chicago}{\@@bibstyle}}
  {
    \usepackage{natbib}
    \bibliographystyle{chicago}
  }
\ifthen{\equal{ieee}{\@@bibstyle}}
  {\bibliographystyle{ieee}}
\ifthen{\equal{ieeetr}{\@@bibstyle}}
  {\bibliographystyle{ieeetr}}
\ifthen{\equal{kluwer}{\@@bibstyle}}
  {
    \usepackage{harvard}
    \bibliographystyle{kluwer}
  }
\ifthen{\equal{pumeunsrt}{\@@bibstyle}}
  {\bibliographystyle{pumeunsrt}}
\ifthen{\equal{plain}{\@@bibstyle}}
  {\bibliographystyle{plain}}
\ifthen{\equal{plainnat}{\@@bibstyle}}
  {
    \usepackage{natbib}
    \renewcommand{\bibname}{{\normalsize\rm REFERENCES}}
    \bibliographystyle{plainnat}
  }
\ifthen{\equal{unsrt}{\@@bibstyle}}
  {\bibliographystyle{unsrt}}
\ifthen{\equal{unsrtnat}{\@@bibstyle}}
  {
    \usepackage{natbib}
    \renewcommand{\bibname}{{\normalsize\rm REFERENCES}}
    \bibliographystyle{unsrtnat}
  }
\renewenvironment{thebibliography}[1]
  {
    \renewcommand*{\baselinestretch}{2.0}\reset@font
    \@@nonchapter{odd}{\@@bibname}{n}{24pt}
    \list
      {\@biblabel{\arabic{enumiv}}}%
      {%
        \settowidth\labelwidth{\@biblabel{#1}}%
        \leftmargin\labelwidth
        \advance\leftmargin\labelsep
        \if@openbib
          \advance\leftmargin\bibindent
          \itemindent -\bibindent
          \listparindent \itemindent
          \parsep \z@
        \fi
        \@@thebibliographyparsep
        \usecounter{enumiv}%
        \let\p@enumiv\@empty
        \renewcommand{\theenumiv}{\arabic{enumiv}}%
      }%
    \if@openbib
      \renewcommand{\newblock}{\par}
    \else
      \renewcommand{\newblock}{\hskip .11em \@plus.33em \@minus.07em}%
    \fi
    \sloppy\clubpenalty4000\widowpenalty4000%
    \sfcode`\.=\@m
  }
  {}
\newboolean{@@inappendix}
\newcommand{\@@appendixname}{Appendix}
\renewcommand{\appendix}{\par
  \setboolean{@@inappendix}{true}
  \setcounter{chapter}{0}%
  \setcounter{section}{0}%
  \coversheet{\uppercase\expandafter{\@@appendixname}}
  \renewcommand{\@chapapp}{\appendixname}%
  \renewcommand{\thechapter}{\Alph{chapter}}
}
\newcommand{\@@appendicesname}{Appendices}
\newcommand{\appendices}{\par
  \setboolean{@@inappendix}{true}
  \setcounter{chapter}{0}%
  \setcounter{section}{0}%
  \coversheet{\uppercase\expandafter{\@@appendicesname}}
  \renewcommand{\@chapapp}{\appendixname}%
  \renewcommand{\thechapter}{\Alph{chapter}}
}
\newcommand{\@@vitaname}{VITA}
\newenvironment{vita}
  {
    \@@startvita
    \@@nonchapter{odd}{\@@vitaname}{y}{0pt}%
  }
  {}
\def\@starttoc#1{%
  \begingroup
    \@input{\jobname.#1}%
    \if@filesw \expandafter\newwrite\csname tf@#1\endcsname
      \immediate\openout \csname tf@#1\endcsname \jobname.#1\relax
    \fi
    \global\@nobreakfalse
  \endgroup
}
\newcommand{\num}[1]{\ensuremath{#1}}
\newcommand{\ten}[1]{\ensuremath{{}\cdot 10^{#1}}}

\setcounter{topnumber}{10}
\renewcommand{\topfraction}{1}
\setcounter{bottomnumber}{10}
\renewcommand{\bottomfraction}{1}
\setcounter{totalnumber}{10}
\renewcommand{\textfraction}{0}
\renewcommand{\floatpagefraction}{0}

\setlength{\floatsep}{18pt plus 3pt minus 3pt}
\setlength{\textfloatsep}{30pt plus 3pt minus 6pt}
\setlength{\intextsep}{18pt plus 3pt minus 3pt}
\setlength{\dblfloatsep}{18pt plus 3pt minus 3pt}
\setlength{\dbltextfloatsep}{30pt plus 3pt minus 6pt}

\newcommand{\Baselinestretch}[1]{\renewcommand{\baselinestretch}{#1}\reset@font}

\def\volume{
  \addtocounter{@@volume}{1}
  \write\@auxout{\string\setcounter{last@@volume}{\the@@volume}}
  \ifthen{\(\boolean{number@@all@@volumes} \and \value{last@@volume}>1\) \or \value{@@volume}>1}
    {
      \addtocontents{toc}{\string\vskip\string\baselineskip \noindent VOLUME \the@@volume}
    }
  \maketitle
}

\makeatother

\raggedbottom